@@ -12,7 +12,7 @@ use anyhow::Result;
 use structopt::StructOpt;
 
 #[derive(Debug, StructOpt)]
-#[structopt(name = "napa", about = "A simple and secure command-line password manager")]
+#[structopt(name = "napa", about = "A simple and secure command line password manager")]
 pub enum Cli {
     #[structopt(about = "Initialize a new database")]
     Init {
